@@ -10,11 +10,7 @@
  *   2) function to obtain the FE coefficients after the estimation is done        *
  *   3) functions to lag variables                                                 *
  *                                                                                 *
- * The algorithm to get the FE coefs is very fast and finds the number             *
- * of references with proba 1. I may write an article in "stg letters" some day to *
- * describe it (actually I should... God give me the time!).                       *
- *                                                                                 *
- * Otherwise, nothing much to say, everything is pretty explicit.                  *
+ * Nothing much to say, everything is pretty explicit.                             *
  *                                                                                 *
  **********************************************************************************/
 
@@ -1048,5 +1044,153 @@ std::string cpp_add_commas(double x, int r = 1, bool whole = true){
 }
 
 
+// [[Rcpp::export]]
+List cpp_find_never_always_treated(IntegerVector cohort, NumericVector period){
+    // Note that both cohort and period are sorted according to cohort
+
+    IntegerVector always_treated;
+    // cohort_ref => the guys that will be out of the interaction
+    IntegerVector cohort_ref;
+
+    int n = cohort.size();
+
+    bool is_pos = false;
+    bool is_neg = false;
+    bool is_ok = false;
+
+    int j = cohort[0];
+    if(period[0] < 0){
+        is_neg = true;
+    } else {
+        is_pos = true;
+    }
+
+    for(int i=1 ; i<n ; ++i){
+
+        if(j == cohort[i]){
+            if(!is_ok){
+                // condition avoids checking period
+                // only worth for very (very) long vectors
+
+                if(period[i] < 0){
+                    is_neg = true;
+                    is_ok = is_pos;
+                } else {
+                    is_pos = true;
+                    is_ok = is_neg;
+                }
+            }
+        } else {
+            // we change IDs
+            if(!is_ok){
+                if(is_pos) always_treated.push_back(j);
+                cohort_ref.push_back(j);
+            }
+
+            // re-init
+            j = cohort[i];
+            is_neg = false;
+            is_pos = false;
+            is_ok = false;
+
+        }
+    }
+
+    // Last element
+    if(!is_ok){
+        if(is_pos) always_treated.push_back(j);
+        cohort_ref.push_back(j);
+    }
+
+    List res;
+    res["always_treated"] = always_treated;
+    res["ref"] = cohort_ref;
+
+    return res;
+}
+
+
+// [[Rcpp::export]]
+IntegerVector cpp_get_first_item(IntegerVector x, int n_items){
+    // observation id of the first occurrence
+    // x ranges from 1 to n_items
+    // we return indexes R style
+
+    int n = x.size();
+    IntegerVector res(n_items);
+
+    for(int i=0 ; i<n ; ++i){
+        if(res[x[i] - 1] == 0){
+            res[x[i] - 1] = i + 1;
+        }
+    }
+
+    return res;
+}
+
+
+// [[Rcpp::export]]
+IntegerVector cpp_combine_clusters(SEXP cluster_list, IntegerVector index){
+    // cluster: list of integer vectors, each ranging from 1 to the number of cases
+    // index: result of order() on the clusters
+
+    if(TYPEOF(cluster_list) != VECSXP){
+        stop("Internal error: Only lists are accepted!");
+    }
+
+    int Q = Rf_length(cluster_list);
+
+    int n = index.size();
+    IntegerVector res(n);
+
+    // Loading the data
+    vector<int*> pcluster(Q);
+    for(int q=0 ; q<Q ; ++q){
+        SEXP cluster_q = VECTOR_ELT(cluster_list, q);
+
+        pcluster[q] = INTEGER(cluster_q);
+    }
+
+    // the observation ID
+    int obs = index[0] - 1;
+
+    // vector holding the current value
+    vector<int> current_value(Q);
+
+    // initialization
+    int counter = 1;
+    res[obs] = counter;
+    for(int q=0 ; q<Q ; ++q){
+        current_value[q] = pcluster[q][obs];
+    }
+
+    // we loop on the vector and flag values that are different
+    int q = 0;
+    for(int i=1 ; i<n ; ++i){
+        obs = index[i] - 1;
+
+        for(q=0 ; q<Q ; ++q){
+            if(pcluster[q][obs] != current_value[q]){
+                break;
+            }
+        }
+
+        // if the condition holds => means the values are different
+        if(q < Q){
+            ++counter;
+            // we save the new values
+            for(; q<Q ; ++q){
+                current_value[q] = pcluster[q][obs];
+            }
+        }
+
+        res[obs] = counter;
+    }
+
+    return res;
+}
+
+
+
 
 
